Index: webrtc/api/rtpsender.h |
diff --git a/webrtc/api/rtpsender.h b/webrtc/api/rtpsender.h |
index 33059416e9a63896217dddca968e22b243a935bf..25cc4ed14a97bc8f73595c1f544d0dc6c1072bd4 100644 |
--- a/webrtc/api/rtpsender.h |
+++ b/webrtc/api/rtpsender.h |
@@ -23,14 +23,14 @@ |
#include "webrtc/base/basictypes.h" |
#include "webrtc/base/criticalsection.h" |
#include "webrtc/base/scoped_ptr.h" |
-#include "webrtc/media/base/audiorenderer.h" |
+#include "webrtc/media/base/audiosource.h" |
namespace webrtc { |
// LocalAudioSinkAdapter receives data callback as a sink to the local |
// AudioTrack, and passes the data to the sink of AudioRenderer. |
class LocalAudioSinkAdapter : public AudioTrackSinkInterface, |
- public cricket::AudioRenderer { |
+ public cricket::AudioSource { |
public: |
LocalAudioSinkAdapter(); |
virtual ~LocalAudioSinkAdapter(); |
@@ -43,10 +43,10 @@ class LocalAudioSinkAdapter : public AudioTrackSinkInterface, |
size_t number_of_channels, |
size_t number_of_frames) override; |
- // cricket::AudioRenderer implementation. |
- void SetSink(cricket::AudioRenderer::Sink* sink) override; |
+ // cricket::AudioSource implementation. |
+ void SetSink(cricket::AudioSource::Sink* sink) override; |
- cricket::AudioRenderer::Sink* sink_; |
+ cricket::AudioSource::Sink* sink_; |
// Critical section protecting |sink_|. |
rtc::CriticalSection lock_; |
}; |
@@ -113,7 +113,7 @@ class AudioRtpSender : public ObserverInterface, |
bool stopped_ = false; |
// Used to pass the data callback from the |track_| to the other end of |
- // cricket::AudioRenderer. |
+ // cricket::AudioSource. |
rtc::scoped_ptr<LocalAudioSinkAdapter> sink_adapter_; |
}; |
@@ -23,14 +23,14 @@ |
namespace webrtc { |
// LocalAudioSinkAdapter receives data callback as a sink to the local |
-// AudioTrack, and passes the data to the sink of AudioRenderer. |
+// AudioTrack, and passes the data to the sink of AudioSource. |
class LocalAudioSinkAdapter : public AudioTrackSinkInterface, |